'use client';
import Image from 'next/image';
import { TVToggle, useTVMode } from '@/components/context/TVMode';
import { ThemeToggle } from '@/components/context/Theme';
import AvatarDropdown from '@/components/auth/AvatarDropdown';

const Header = () => {
  const { tvMode } = useTVMode();
  if (tvMode) {
    return (
      <div className='absolute top-4 right-2'>
        <div className='flex flex-row my-auto items-center pt-2 pr-0 md:pt-4'>
          <TVToggle />
        </div>
      </div>
    );
  } else {
    return (
      <header className='w-full py-2 pt-6 md:py-5'>
        <div className='absolute top-4 right-6'>
          <div className='flex flex-row my-auto items-center pt-2 pr-0 md:pt-4 md:pr-8'>
            <TVToggle />
            <ThemeToggle />
            <AvatarDropdown />
          </div>
        </div>
        <div
          className='flex flex-row items-center text-center
            justify-center sm:ml-0 p-4 mt-10 sm:mt-0'
        >
          <Image
            src='/images/tech_tracker_logo.png'
            alt='Tech Tracker Logo'
            width={100}
            height={100}
            className='max-w-[40px] md:max-w-[120px]'
          />
          <h1
            className='title-text text-sm md:text-4xl lg:text-8xl
            bg-gradient-to-r from-[#bec8e6] via-[#F0EEE4] to-[#FFF8E7]
            font-bold pl-2 md:pl-12 text-transparent bg-clip-text'
          >
            Tech Tracker
          </h1>
        </div>
      </header>
    );
  }
};
export default Header;
